namespace Quik
{
    /// <summary>
    /// A 2 dimensional Vector.
    /// </summary>
    public struct QuikVec2
    {
        public float X;
        public float Y;
    }

    /// <summary>
    /// A RGBA color value.
    /// </summary>
    public struct QuikColor
    {
        /// <summary>
        /// Red channel.
        /// </summary>
        public byte R;
        /// <summary>
        /// Green channel.
        /// </summary>
        public byte G;
        /// <summary>
        /// Blue channel.
        /// </summary>
        public byte B;
        /// <summary>
        /// Alpha channel.
        /// </summary>
        public byte A;
    }
    
    /// <summary>
    /// A bezier curve segment.
    /// </summary>
    public struct QuikBezier
    {
        /// <summary>
        /// Segment start point.
        /// </summary>
        public QuikVec2 Start;
        
        /// <summary>
        /// Start point control point.
        /// </summary>
        public QuikVec2 ControlA;
        
        /// <summary>
        /// End point control point.
        /// </summary>
        public QuikVec2 ControlB;
        
        /// <summary>
        /// Segment end point.
        /// </summary>
        public QuikVec2 End;
    }

    /// <summary>
    /// A line segment.
    /// </summary>
    public struct QuikLine
    {
        /// <summary>
        /// Start point.
        /// </summary>
        public QuikVec2 Start;
        
        /// <summary>
        /// End point.
        /// </summary>
        public QuikVec2 End;
    }

    /// <summary>
    /// A rectangle.
    /// </summary>
    public struct QuikRectangle
    {
        /// <summary>
        /// Rectangle minimum point.
        /// </summary>
        public QuikVec2 Min;
        
        /// <summary>
        /// Rectangle maximum point.
        /// </summary>
        public QuikVec2 Max;
    }

    /// <summary>
    /// An ellipse.
    /// </summary>
    /// <remarks>It is undefined to have an ellipse with non-orthogonal axes.</remarks>
    public struct QuikEllipse
    {
        /// <summary>
        /// Ellipse center point.
        /// </summary>
        public QuikVec2 Center;
        
        /// <summary>
        /// First ellipse axis.
        /// </summary>
        public QuikVec2 AxisA;
        
        /// <summary>
        /// Second ellipse axis.
        /// </summary>
        public QuikVec2 AxisB;
    }

    /// <summary>
    /// A triangle.
    /// </summary>
    public struct QuikTriangle
    {
        /// <summary>
        /// First vertex.
        /// </summary>
        public QuikVec2 A;
        
        /// <summary>
        /// Second vertex.
        /// </summary>
        public QuikVec2 B;
        
        /// <summary>
        /// Third vertex.
        /// </summary>
        public QuikVec2 C;
    }
}