namespace Quik
{
    /// <summary>
    /// A line stipple pattern.
    /// </summary>
    public struct QuikStipplePattern
    {
        /// <summary>
        /// The stipple pitch value.
        /// </summary>
        public float Pitch;

        /// <summary>
        /// The stipple duty cycle.
        /// </summary>
        public float DutyCycle;
        
        public QuikStipplePattern(float pitch, float dutyCycle)
        {
            Pitch = pitch;
            DutyCycle = dutyCycle;
        }
        
        public static QuikStipplePattern None => new QuikStipplePattern(0.0f, 1.0f);
    }
    
    /// <summary>
    /// Stroke style for lines and borders.
    /// </summary>
    public class QuikStrokeStyle
    {
        /// <summary>
        /// Stroke color.
        /// </summary>
        public QuikColor Color { get; set; }

        /// <summary>
        /// Stroke width.
        /// </summary>
        public float Width { get; set; }

        /// <summary>
        /// Stroke stipple pattern.
        /// </summary>
        public QuikStipplePattern StipplePattern { get; set; }

        public QuikStrokeStyle()
        {
        }
        
        public QuikStrokeStyle(QuikColor color, float width, QuikStipplePattern pattern)
        {
            Color = color;
            Width = width;
            StipplePattern = pattern;
        }

        public QuikStrokeStyle(QuikColor color, float width) : this(color, width, QuikStipplePattern.None)
        {
        }
    }

    /// <summary>
    /// Fill style for rectangles and the like.
    /// </summary>
    public class QuikFillStyle
    {
        public QuikColor Color { get; set; }
    }
}